package dev.garrettmills.csx.matterlinkreboot;

import net.minecraftforge.common.ForgeConfigSpec;

public class MatterlinkRebootConfig {
    private static final ForgeConfigSpec.Builder BUILDER = new ForgeConfigSpec.Builder();
    public static final General GENERAL = new General(BUILDER);
    public static final ForgeConfigSpec spec = BUILDER.build();

    public static class General {
        public final ForgeConfigSpec.ConfigValue<Boolean> BridgeEnabled;
        public final ForgeConfigSpec.ConfigValue<String> BridgeHost;
        public final ForgeConfigSpec.ConfigValue<Integer> BridgePort;
        public final ForgeConfigSpec.ConfigValue<String> BridgeProtocol;
        public final ForgeConfigSpec.ConfigValue<String> BridgeGateway;
        public final ForgeConfigSpec.ConfigValue<String> DefaultAvatar;
        public final ForgeConfigSpec.ConfigValue<Integer> PollingInterval;

        public General(ForgeConfigSpec.Builder builder) {
            builder.push("General");

            BridgeEnabled = builder.comment("Enables/disables the chat entire chat bridge. (true, false) [true]")
                    .define("bridgeEnabled", false);

            BridgeHost = builder.comment("Hostname or IP address of the Matterbridge server. [127.0.0.1]")
                    .define("bridgeHost", "127.0.0.1");

            BridgePort = builder.comment("Port of the Matterbridge server on the host. [4242]")
                    .define("bridgePort", 4242);

            BridgeProtocol = builder.comment("Protocol to use to interact with the Matterbridge API. (http, https) [http]")
                    .define("bridgeProtocol", "http");

            BridgeGateway = builder.comment("Name of the Matterbridge gateway to push messages to. [matterbridge]")
                    .define("bridgeGateway", "gateway");

            DefaultAvatar = builder.comment("Default URL to use for the avatar for outgoing messages. [https://secure.gravatar.com/avatar/matterlinkreboot.jpg]")
                    .define("defaultAvatar", "https://secure.gravatar.com/avatar/matterlinkreboot.jpg");

            PollingInterval = builder.comment("Interval (in seconds) to poll the Matterbridge server to check for new messages. [2]")
                    .define("pollingInterval", 2);

            builder.pop();
        }
    }
}
